@@ -123,7 +123,7 @@ def train_epoch(net, trainer, loss, data_load, epochs):
             # l 必须是标量
             l.mean().backward()
             trainer.step()
-            print('batch loss: {}'.format(l))
+            # print('batch loss: {}'.format(l))
 
 
 def train_one_epoch_loss_acc(net, train_iter, loss, updater):
